# TODO:
1. This
1. windows builds (automated??)
1. non-playsound osx
1. HTTP command receiver (lioran!)
1. custom hook code - lioran example? obs websocket?
1. more flexible command triggers (regex??)
1. bundle audio bleeps, learn how to ref manifest files
1. verify file exists before queueing sound?
